==> tuia-client-0.5.4-20181116.055351-4-sources.jar: cn/com/tuia/advert/model/ObtainEncourageAdvertReq.java <==
package cn.com.tuia.advert.model;

import com.alibaba.fastjson.JSON;
import org.joda.time.DateTime;

import java.io.Serializable;
import java.util.Map;

/**
 * 激励广告请求
 */
public class ObtainEncourageAdvertReq implements Serializable {

    private static final long serialVersionUID = 7371676541293127274L;

    /**
     * 点击按钮的用户id
     */
    private Long consumerId;

    /**
     * 点击按钮的客户端的UA
     */
    private String ua;

    /**
     * 点击按钮的客户端的ip
     */
    private String ip;

    /**
     * 发生点击事件的app的id
     */
    private Long appId;

    /**
     * 福袋被添加的活动ID或者直投页ID
     */
    private Long activityId;

    /**
     * 客户端时间戳，毫秒
     */
    private Long timestamp;

    /**
     * 用户使用系统
     */
    private String os;

    /**
     * 点击：0，曝光：1，请求：2，发券：3，计费：4
     */
    private String type;

    private String userAgent;

    /**
     * 在cookie中写入的设备id
     */
    private String deviceId;

    /**
     * 当前系统时间
     */
    private String time;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * 广告ID
     */
    private Long advertId;

    /**
     * 页面类型，1-活动、2-直投页
     */
    private Integer pageType;

    /**
     * 日志扩展map，仅用于记录日志
     */
    private Map<String, String> logExtMap;

    public ObtainEncourageAdvertReq() {
        super();
        DateTime nowTime = new DateTime();
        this.time = nowTime.toString("yyyy-MM-dd HH:mm:ss");
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public String getOs() {
        return os;
    }

    public void setOs(String os) {
        this.os = os;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Map<String, String> getLogExtMap() {
        return logExtMap;
    }

    public void setLogExtMap(Map<String, String> logExtMap) {
        this.logExtMap = logExtMap;
    }

    @Override
    public String toString() {
        return JSON.toJSONString(this);
    }
}

==> tuia-client-0.5.8-20181217.021127-11-sources.jar: cn/com/tuia/advert/model/ObtainEncourageAdvertReq.java <==
package cn.com.tuia.advert.model;

import com.alibaba.fastjson.JSON;
import org.joda.time.DateTime;

import java.io.Serializable;
import java.util.Map;

/**
 * 激励广告请求
 */
public class ObtainEncourageAdvertReq implements Serializable {

    private static final long serialVersionUID = 7371676541293127274L;

    /**
     * 点击按钮的用户id
     */
    private Long consumerId;

    /**
     * 点击按钮的客户端的UA
     */
    private String ua;

    /**
     * 点击按钮的客户端的ip
     */
    private String ip;

    /**
     * 发生点击事件的app的id
     */
    private Long appId;

    /**
     * 福袋被添加的活动ID或者直投页ID
     */
    private Long activityId;

    /**
     * 激励广告使用的虚拟活动id
     */
    private Long virtualActivityId;

    /**
     * 客户端时间戳，毫秒
     */
    private Long timestamp;

    /**
     * 用户使用系统
     */
    private String os;

    /**
     * 点击：0，曝光：1，请求：2，发券：3，计费：4
     */
    private String type;

    private String userAgent;

    /**
     * 在cookie中写入的设备id
     */
    private String deviceId;

    /**
     * 当前系统时间
     */
    private String time;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * 广告ID
     */
    private Long advertId;

    /**
     * 页面类型，1-活动、2-直投页
     */
    private Integer pageType;

    /**
     * 分流标识
     */
    private Long styleType;

    //流量来源,1-推啊(默认)，2-兑吧
    private Integer flowSource;

    /**
     * 日志扩展map，仅用于记录日志
     */
    private Map<String, String> logExtMap;


    /**
     * 激励广告打得虚拟广告位id
     */
    private Long virtualSlotId;

    /** 活动使用类型，0：兑吧活动,2:推啊活动。 */
    private Integer             activityUseType;

    public Long getVirtualActivityId() {
        return virtualActivityId;
    }

    public void setVirtualActivityId(Long virtualActivityId) {
        this.virtualActivityId = virtualActivityId;
    }

    /**
     * activityUseType.
     *
     * @return the activityUseType
     * @since JDK 1.8
     */
    public Integer getActivityUseType() {
        return activityUseType;
    }

    /**
     * activityUseType.
     *
     * @param activityUseType the activityUseType to set
     * @since JDK 1.8
     */
    public void setActivityUseType(Integer activityUseType) {
        this.activityUseType = activityUseType;
    }

    public Long getVirtualSlotId() {
        return virtualSlotId;
    }

    public void setVirtualSlotId(Long virtualSlotId) {
        this.virtualSlotId = virtualSlotId;
    }

    public ObtainEncourageAdvertReq() {
        super();
        DateTime nowTime = new DateTime();
        this.time = nowTime.toString("yyyy-MM-dd HH:mm:ss");
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Long getStyleType() {
        return styleType;
    }

    public void setStyleType(Long styleType) {
        this.styleType = styleType;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Integer getFlowSource() {
        return flowSource;
    }

    public void setFlowSource(Integer flowSource) {
        this.flowSource = flowSource;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public String getOs() {
        return os;
    }

    public void setOs(String os) {
        this.os = os;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Map<String, String> getLogExtMap() {
        return logExtMap;
    }

    public void setLogExtMap(Map<String, String> logExtMap) {
        this.logExtMap = logExtMap;
    }

    @Override
    public String toString() {
        return JSON.toJSONString(this);
    }
}
